@@ -1,6 +1,6 @@
 /*
  * boxes - Command line filter to draw/remove ASCII boxes around text
- * Copyright (c) 1999-2021 Thomas Jensen and the boxes contributors
+ * Copyright (c) 1999-2023 Thomas Jensen and the boxes contributors
  *
  * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
  * License, version 3, as published by the Free Software Foundation.
@@ -25,6 +25,10 @@
 
 #define _GNU_SOURCE
 
+#elif defined(__APPLE__)
+
+#define _DARWIN_C_SOURCE
+
 #elif defined(__sun__)
 
 #define _POSIX_SOURCE
