@@ -1,6 +1,6 @@
 /*
  * boxes - Command line filter to draw/remove ASCII boxes around text
- * Copyright (c) 1999-2021 Thomas Jensen and the boxes contributors
+ * Copyright (c) 1999-2023 Thomas Jensen and the boxes contributors
  *
  * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
  * License, version 3, as published by the Free Software Foundation.
@@ -983,10 +983,10 @@ int remove_box()
                 fprintf(stderr, "u32_move(\"%s\", \"%s\", %d); // posmap[c]=%d\n",
                         u32_strconv_to_output(input.lines[j].mbtext),
                         u32_strconv_to_output(input.lines[j].mbtext + input.lines[j].posmap[c]),
-                        (int) (input.lines[j].num_chars - c + 1), (int) input.lines[j].posmap[c]);
+                        (int) (input.lines[j].num_chars - input.lines[j].posmap[c] + 1), (int) input.lines[j].posmap[c]);
             #endif
             u32_move(input.lines[j].mbtext, input.lines[j].mbtext + input.lines[j].posmap[c],
-                     input.lines[j].num_chars - c + 1);  /* +1 for zero byte */
+                     input.lines[j].num_chars - input.lines[j].posmap[c] + 1);  /* +1 for zero byte */
             input.lines[j].num_chars -= c;
         }
     }
