@@ -1,6 +1,6 @@
 /*
  * boxes - Command line filter to draw/remove ASCII boxes around text
- * Copyright (c) 1999-2021 Thomas Jensen and the boxes contributors
+ * Copyright (c) 1999-2023 Thomas Jensen and the boxes contributors
  *
  * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
  * License, version 3, as published by the Free Software Foundation.
@@ -22,7 +22,7 @@
 
 
 int remove_box();
-void output_input();
+void output_input(const int trim_only);
 
 
 #endif /*REMOVE_H*/
